@@ -12,7 +12,7 @@ from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH
 from beanstalk.decorators import beanstalk_role
 from beanstalk.paths.server import (project_base_path, project_source_path, project_logs_path, project_venv_path,
                                     project_uwsgi_path, apache_conf_path, app_ports_path)
-from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, set_verbose_level, run_hooked_actions
+from beanstalk.tasks.utils import load_role_settings, set_verbose_level, run_hooked_actions
 from beanstalk.console.titles import tool_title, section_title, separator
 
 
@@ -22,7 +22,7 @@ from beanstalk.console.titles import tool_title, section_title, separator
 
 @task
 @beanstalk_role('server')
-def setup(**settings_patches):
+def setup(settings_path=None, **settings_patches):
     """Setup remote base of beanstalk-stack in this server
     """
     print tool_title('Beanstalk-stack server setup tool')
@@ -30,7 +30,7 @@ def setup(**settings_patches):
 
     # Load beanstalk settings
     settings_patches = eval_kwargs(settings_patches)
-    beanstalk_settings = load_beanstalk_settings(**settings_patches)
+    beanstalk_settings = load_role_settings(additional_settings_path=settings_path, **settings_patches)
     beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
     set_verbose_level()
 
@@ -189,11 +189,11 @@ def setup(**settings_patches):
 
 @task
 @beanstalk_role('server')
-def create_app(project_name, **settings_patches):
+def create_app(project_name, settings_path=None, **settings_patches):
     """Create an app
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     env.project_name = project_name
     set_verbose_level()
 
@@ -288,11 +288,11 @@ def create_app(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def delete_app(project_name, **settings_patches):
+def delete_app(project_name, settings_path=None, **settings_patches):
     """Delete an app
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     env.project_name = project_name
 
@@ -323,11 +323,11 @@ def delete_app(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def install_app(project_name, **settings_patches):
+def install_app(project_name, settings_path=None, **settings_patches):
     """Install an app (call when u updated the code)
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     env.project_name = project_name
 
@@ -384,11 +384,11 @@ def install_app(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def reload_app(project_name, **settings_patches):
+def reload_app(project_name, settings_path=None, **settings_patches):
     """Update an app (call when u updated the code)
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
     env.project_name = project_name
 
@@ -402,11 +402,11 @@ def reload_app(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def build_venv(project_name, **settings_patches):
+def build_venv(project_name, settings_path=None, **settings_patches):
     """Build virtual env of target app.
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
 
     # path
@@ -427,11 +427,11 @@ def build_venv(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def app_info(project_name, **settings_patches):
+def app_info(project_name, settings_path=None, **settings_patches):
     """Get info of an app
     """
     settings_patches = eval_kwargs(settings_patches)
-    beanstalk_settings = load_beanstalk_settings(**settings_patches)
+    beanstalk_settings = load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
 
     # Gather information
@@ -481,11 +481,11 @@ def app_info(project_name, **settings_patches):
 
 @task
 @beanstalk_role('server')
-def list_apps(**settings_patches):
+def list_apps(settings_path=None, **settings_patches):
     """Get list of apps
     """
     settings_patches = eval_kwargs(settings_patches)
-    beanstalk_settings = load_beanstalk_settings(**settings_patches)
+    beanstalk_settings = load_role_settings(additional_settings_path=settings_path, **settings_patches)
     set_verbose_level()
 
     apps = os.listdir(os.path.join(beanstalk_settings['BEANSTALK_STACK_BASE'], 'apps/'))
@@ -498,11 +498,11 @@ def list_apps(**settings_patches):
 
 @task
 @beanstalk_role('server')
-def commit_app(project_name, **settings_patches):
+def commit_app(project_name, settings_path=None, **settings_patches):
     """Commit app
     """
     settings_patches = eval_kwargs(settings_patches)
-    load_beanstalk_settings(**settings_patches)
+    load_role_settings(additional_settings_path=settings_path, **settings_patches)
     env.project_name = project_name
     set_verbose_level()
 
